#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2014 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
Section functionality for fee views
"""

from zope.security.proxy import removeSecurityProxy

from schooltool.app import membership
from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.course import interfaces
from schooltool.schoolyear.interfaces import ISchoolYear
from schooltool.schoolyear.interfaces import ISchoolYearContainer
from schooltool.term.interfaces import ITerm


def get_active_year():
    schoolyears = ISchoolYearContainer(ISchoolToolApplication(None))
    return schoolyears.getActiveSchoolYear()


def is_student(person, only_active_year=False):
    active = get_active_year()
    person = removeSecurityProxy(person)
    group_relation = membership.Membership
    for link_info in group_relation.bind(member=person).all().relationships:
        target = removeSecurityProxy(link_info.target)
        schoolyear = None
        if interfaces.ISection.providedBy(target):
            schoolyear = ISchoolYear(ITerm(target))
        elif target.__name__ == 'students':
            schoolyear = ISchoolYear(target.__parent__)
        if (schoolyear is not None and
            (not only_active_year or schoolyear == active)):
            return True
    return False
