#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2015 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
Evolve database to generation 2.

Adds receipt numbers to existing credits
"""

from zope.app.generations.utility import getRootFolder

from schooltool.fee.interfaces import IFeeContainer
from schooltool.fee.interfaces import ICredit
from schooltool.fee.interfaces import IReceiptNumbers


def evolve(context):
    app = getRootFolder(context)
    numbers = IReceiptNumbers(app)
    persons = app['persons']
    without_receipt = []
    for person in persons.values():
        fees = IFeeContainer(person)
        for fee in fees.values():
            if ICredit.providedBy(fee):
                if not fee.receipt:
                    without_receipt.append(fee)
                else:
                    numbers.last += 1
    for credit in sorted(without_receipt, key=lambda c: (c.date, c.title or '')):
        credit.receipt = unicode(numbers)
        numbers.last += 1
