#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2015 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
Evolve database to generation 3.

Adds missing recurrences to group members
"""

from zope.app.generations.utility import getRootFolder
from zope.component.hooks import getSite, setSite

from schooltool.schoolyear.interfaces import ISchoolYearContainer
from schooltool.group.interfaces import IGroupContainer

from schooltool.fee.interfaces import IFeeContainer
from schooltool.fee.fee import Debit

def get_recurrences(fees, master):
    result = []
    for item in fees.values():
        if item.master == master:
            result.append(item)
    return result


def evolve(context):
    app = getRootFolder(context)
    old_site = getSite()
    setSite(app)
    schoolyears = ISchoolYearContainer(app)
    for schoolyear in schoolyears.values():
        groups = IGroupContainer(schoolyear)
        for group in groups.values():
            group_fees = IFeeContainer(group)
            masters = [fee.__name__ for fee in group_fees.values()
                       if not fee.master]
            for master in masters:
                for person in group.members:
                    person_fees = IFeeContainer(person)
                    if master in person_fees:
                        for recurrence in get_recurrences(group_fees, master):
                            if recurrence.__name__ not in person_fees:
                                recurrence_fee = Debit()
                                recurrence_fee.date = recurrence.date
                                recurrence_fee.last_date = recurrence.last_date
                                recurrence_fee.title = recurrence.title
                                recurrence_fee.label = recurrence.label
                                recurrence_fee.description = recurrence.description
                                recurrence_fee.amount = recurrence.amount
                                recurrence_fee.master = recurrence.master
                                person_fees[recurrence.__name__] = recurrence_fee
    setSite(old_site)
